# Dashboards
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/dashboards?version=CLOUD#overview)
  * [Creating a Dashboard](https://help.sap.com/docs/leanix/ea/dashboards?version=CLOUD#creating-a-dashboard)
  * [Global Filtering in Dashboards](https://help.sap.com/docs/leanix/ea/dashboards?version=CLOUD#global-filtering-in-dashboards)
  * [Editing a Dashboard](https://help.sap.com/docs/leanix/ea/dashboards?version=CLOUD#editing-a-dashboard)
  * [Setting the Default Dashboard](https://help.sap.com/docs/leanix/ea/dashboards?version=CLOUD#setting-the-default-dashboard)
  * [Sharing a Dashboard](https://help.sap.com/docs/leanix/ea/dashboards?version=CLOUD#sharing-a-dashboard)
  * [Adding a Dashboard to a Collection](https://help.sap.com/docs/leanix/ea/dashboards?version=CLOUD#adding-a-dashboard-to-a-collection)
  * [Adding a Dashboard to Favorites](https://help.sap.com/docs/leanix/ea/dashboards?version=CLOUD#adding-a-dashboard-to-favorites)


View all
Dashboards enable you to consolidate and interpret data in one place, facilitating informed decision-making and promoting efficient task management. Learn how to create, customize, and manage dashboards.
